@@ -2,7 +2,6 @@ package cache
 
 import (
 	"encoding/gob"
-	"sync"
 	"time"
 )
 
@@ -10,15 +9,12 @@ func init() {
 	gob.Register(&Entry[any]{})
 	gob.Register(Template{})
 	gob.Register(SimpleTemplate{})
+	gob.Register((*Duration)(nil))
+	gob.Register(map[string]bool{})
 }
 
 const (
-	FileName = "omp.cache"
-)
-
-var (
-	sessionID string
-	once      sync.Once
+	DeviceStore = "omp.cache"
 )
 
 const (
