@@ -2,7 +2,7 @@ package cli
 
 import (
 	"fmt"
-	"strings"
+	"os"
 	"time"
 
 	"github.com/jandedobbeleer/oh-my-posh/src/cache"
@@ -32,6 +32,7 @@ This command is used to get the value of the following variables:
 		"accent",
 		"toggles",
 		"width",
+		cache.TTL,
 	},
 	Args: NoArgsOrOneValidArg,
 	Run: func(cmd *cobra.Command, args []string) {
@@ -46,21 +47,16 @@ This command is used to get the value of the following variables:
 		}
 
 		flags := &runtime.Flags{
-			Shell: shellName,
+			Shell: os.Getenv("POSH_SHELL"),
 		}
 
 		env := &runtime.Terminal{}
 		env.Init(flags)
 
-		cache.Init(shellName, cache.Persist)
-
-		defer func() {
-			cache.Close()
-		}()
-
 		switch args[0] {
 		case "shell":
 			fmt.Print(env.Shell())
+			return
 		case "accent":
 			rgb, err := color.GetAccentColor(env)
 			if err != nil {
@@ -69,23 +65,7 @@ This command is used to get the value of the following variables:
 			}
 			accent := color2.RGB(rgb.R, rgb.G, rgb.B)
 			fmt.Print("#" + accent.Hex())
-		case "toggles":
-			var toggles []string
-
-			togglesCache, _ := cache.Get[string](cache.Session, cache.TOGGLECACHE)
-			if len(togglesCache) != 0 {
-				toggles = strings.Split(togglesCache, ",")
-			}
-
-			if len(toggles) == 0 {
-				fmt.Println("No segments are toggled off")
-				return
-			}
-
-			fmt.Println("Toggled off segments:")
-			for _, toggle := range toggles {
-				fmt.Println("- " + toggle)
-			}
+			return
 		case "width":
 			width, err := env.TerminalWidth()
 			if err != nil {
@@ -94,6 +74,29 @@ This command is used to get the value of the following variables:
 			}
 
 			fmt.Print(width)
+			return
+		}
+
+		cache.Init(env.Shell(), cache.Persist)
+
+		defer func() {
+			cache.Close()
+		}()
+
+		switch args[0] {
+		case "toggles":
+			togglesMap, _ := cache.Get[map[string]bool](cache.Session, cache.TOGGLECACHE)
+			if len(togglesMap) == 0 {
+				fmt.Println("No segments are toggled off")
+				return
+			}
+
+			fmt.Println("Toggled off segments:")
+			for toggle := range togglesMap {
+				fmt.Println("- " + toggle)
+			}
+		case cache.TTL:
+			fmt.Print(cache.GetTTL())
 		default:
 			_ = cmd.Help()
 		}
@@ -102,5 +105,4 @@ This command is used to get the value of the following variables:
 
 func init() {
 	RootCmd.AddCommand(getCmd)
-	getCmd.Flags().StringVar(&shellName, "shell", "", "the shell to print for")
 }
