@@ -8,7 +8,7 @@ import (
 	"net/url"
 
 	"github.com/jandedobbeleer/oh-my-posh/src/log"
-	"github.com/jandedobbeleer/oh-my-posh/src/properties"
+	"github.com/jandedobbeleer/oh-my-posh/src/segments/options"
 )
 
 type Owm struct {
@@ -23,11 +23,11 @@ type Owm struct {
 
 const (
 	// APIKey openweathermap api key
-	APIKey properties.Property = "api_key"
+	APIKey options.Option = "api_key"
 	// Location openweathermap location
-	Location properties.Property = "location"
+	Location options.Option = "location"
 	// Units openweathermap units
-	Units properties.Property = "units"
+	Units options.Option = "units"
 	// CacheKeyResponse key used when caching the response
 	CacheKeyResponse string = "owm_response"
 	// CacheKeyURL key used when caching the url responsible for the response
@@ -70,7 +70,7 @@ func (d *Owm) Template() string {
 func (d *Owm) getResult() (*owmDataResponse, error) {
 	response := new(owmDataResponse)
 
-	apikey := properties.OneOf(d.props, d.env.Getenv(OWMAPIKey), APIKey, "apiKey")
+	apikey := options.OneOf(d.options, d.env.Getenv(OWMAPIKey), APIKey, "apiKey")
 	if apikey == "" {
 		apikey = "."
 	}
@@ -79,15 +79,15 @@ func (d *Owm) getResult() (*owmDataResponse, error) {
 		return nil, errors.New("no api key found")
 	}
 
-	location := d.props.GetString(Location, d.env.Getenv(OWMLocationKey))
+	location := d.options.String(Location, d.env.Getenv(OWMLocationKey))
 	if location == "" {
 		return nil, errors.New("no location found")
 	}
 
 	location = url.QueryEscape(location)
 
-	units := d.props.GetString(Units, "standard")
-	httpTimeout := d.props.GetInt(properties.HTTPTimeout, properties.DefaultHTTPTimeout)
+	units := d.options.String(Units, "standard")
+	httpTimeout := d.options.Int(options.HTTPTimeout, options.DefaultHTTPTimeout)
 
 	d.URL = fmt.Sprintf("https://api.openweathermap.org/data/2.5/weather?q=%s&units=%s&appid=%s", location, units, apikey)
 
@@ -105,7 +105,7 @@ func (d *Owm) getResult() (*owmDataResponse, error) {
 }
 
 func (d *Owm) setStatus() error {
-	units := d.props.GetString(Units, "standard")
+	units := d.options.String(Units, "standard")
 
 	q, err := d.getResult()
 	if err != nil {
